package com.tcl.factory.utils;

import android.graphics.drawable.Drawable;

public class AppInfo {

	private String mPkg;
	private String mActivity;
	private int mAddedFlag = 0;
	private int id = 0;
	private String mAppName;
	private Drawable mDrawable;

	public String getmPkg() {
		return mPkg;
	}

	public void setmPkg(String mPkg) {
		this.mPkg = mPkg;
	}

	public String getmActivity() {
		return mActivity;
	}

	public void setmActivity(String mActivity) {
		this.mActivity = mActivity;
	}

	public int getmAddedFlag() {
		return mAddedFlag;
	}

	public void setmAddedFlag(int mAddedFlag) {
		this.mAddedFlag = mAddedFlag;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getmAppName() {
		return mAppName;
	}

	public void setmAppName(String mAppName) {
		this.mAppName = mAppName;
	}

	public Drawable getmDrawable() {
		return mDrawable;
	}

	public void setmDrawable(Drawable mDrawable) {
		this.mDrawable = mDrawable;
	}

}
